package com.muyu.marketing.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.marketing.domain.model.ActivityTeamProductSkuAddModel;
import com.muyu.marketing.domain.model.ActivityTeamProjectSkuInfoUpdModel;
import com.muyu.marketing.domain.model.ActivityTeamSkuUpdModel;
import lombok.*;
import lombok.experimental.SuperBuilder;

import java.math.BigDecimal;

@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@TableName(value = "activity_team_product_sku_info", autoResultMap = true)
public class ActivityTeamProductSkuInfo extends BaseEntity {

    /**
     * 主键
     */
    @TableId(value = "id", type = IdType.AUTO)
    private long id;
    /**
     * 活动ID
     */
    private Long teamId;
    /**
     * 商品ID
     */
    private Long productId;
    /**
     * 商品SKU
     */
    private String productSku;
    /**
     * 拼团库存
     */
    private Long teamStock;
    /**
     * 剩余库存
     */
    private Long remainStock;
    /**
     * 拼团价格
     */
    private BigDecimal teamPrice;

    /**
     * 通过模型钢构件对象
     *
     * @param activityTeamProductSkuAddModel 模型
     * @return 对象
     */
    public static ActivityTeamProductSkuInfo modelBuild(ActivityTeamProductSkuAddModel activityTeamProductSkuAddModel) {
        return ActivityTeamProductSkuInfo.builder()
                .productId(activityTeamProductSkuAddModel.getProductId())
                .teamId(activityTeamProductSkuAddModel.getTeamId())
                .productSku(activityTeamProductSkuAddModel.getSku())
                .teamStock(activityTeamProductSkuAddModel.getTeamStock())
                .remainStock(activityTeamProductSkuAddModel.getTeamStock())
                .teamPrice(activityTeamProductSkuAddModel.getTeamPrice())
                .build();
    }

    /**
     * 修改对象
     */

    public static ActivityTeamProductSkuInfo updModel(ActivityTeamProjectSkuInfoUpdModel activityTeamProjectSkuInfoUpdModel) {
        return ActivityTeamProductSkuInfo.builder()
                .id(activityTeamProjectSkuInfoUpdModel.getId())
                .teamId(activityTeamProjectSkuInfoUpdModel.getTeamId())
                .productId(activityTeamProjectSkuInfoUpdModel.getProductId())
                .productSku(activityTeamProjectSkuInfoUpdModel.getProductSku())
                .teamStock(activityTeamProjectSkuInfoUpdModel.getTeamStock())
                .remainStock(activityTeamProjectSkuInfoUpdModel.getTeamStock())
                .teamPrice(activityTeamProjectSkuInfoUpdModel.getTeamPrice())
                .build();
    }

    /**
     * 修改Suk信息
     *
     * @param activityTeamSkuUpdModel
     * @return
     */

    public static ActivityTeamProductSkuInfo updSuk(ActivityTeamSkuUpdModel activityTeamSkuUpdModel) {
        return ActivityTeamProductSkuInfo.builder()
                .id(activityTeamSkuUpdModel.getId())
                .teamPrice(activityTeamSkuUpdModel.getTeamPrice())
                .teamStock(activityTeamSkuUpdModel.getTeamStock())
                .build();
    }

//    /**
//     * 批量添加suk信息
//     *
//     * @param activityTeamSkuAddModel
//     * @return
//     */
//    public static ActivityTeamProductSkuInfo addBach(ActivityTeamSkuAddModel activityTeamSkuAddModel) {
//        return ActivityTeamProductSkuInfo.builder()
//                .teamId(activityTeamSkuAddModel.getTeamId())
//                .productId(activityTeamSkuAddModel.getProductId())
//                .productSku(activityTeamSkuAddModel.getProductSku())
//                .teamStock(activityTeamSkuAddModel.getTeamStock())
//                .teamPrice(activityTeamSkuAddModel.getTeamPrice())
//                .build();
//    }

}
